"""Provide Backup process methods for mongodb."""
import os
import shlex
import subprocess

try:
    from charmhelpers.core.hookenv import action_get, action_set, action_fail
except ImportError:
    subprocess.check_call(["apt-get", "install", "-y", "python3-pip"])
    subprocess.check_call(["pip3", "install", "charmhelpers"])
    from charmhelpers.core.hookenv import action_get, action_set, action_fail


def mkdir(dir):
    return os.makedirs(dir)


def execute(command, current_working_directory):
    return subprocess.check_output(shlex.split(command), cwd=current_working_directory)


def dump():
    args = str(action_get("args")).strip()
    dir = str(action_get("workingDir"))
    backup_command("mongodump", args, dir)


def restore():
    args = str(action_get("args")).strip()
    dir = str(action_get("workingDir"))
    backup_command("mongorestore", args, dir)


def backup_command(cmd, args, dir):
    try:
        mkdir(dir)
    except OSError:
        pass  # Ignoring, the directory already exists
    except Exception as e:
        action_set({"directory creation exception": e})
        action_fail(str(e))
        return

    command = cmd + " " + args
    command = command.strip()
    action_set({"command": command, "working-dir": dir})
    try:
        output = execute(command, dir)
        action_set({"output": output})
    except subprocess.CalledProcessError as e:
        action_set({"error_code": e.returncode, "exception": e, "output": e.output})
        action_fail(str(e))
    except Exception as e:
        action_set({"exception": e})
        action_fail(str(e))
