"""Test the backup module."""
import unittest

import backup

from mock import call, create_autospec


def mock_action_get(key):
    return {"workingDir": "this/dir", "args": "-arg1 -arg2"}[key]


class TestBackups(unittest.TestCase):
    def setUp(self):
        self.original = [
            backup.mkdir,
            backup.execute,
            backup.action_set,
            backup.action_fail,
            backup.action_get,
        ]
        backup.mkdir = create_autospec(backup.mkdir, return_value=True)
        backup.execute = create_autospec(backup.execute, return_value="output")
        backup.action_set = create_autospec(backup.action_set, return_value=None)
        backup.action_fail = create_autospec(backup.action_fail, return_value=None)
        backup.action_get = mock_action_get

    def tearDown(self):
        (
            backup.mkdir,
            backup.execute,
            backup.action_set,
            backup.action_fail,
            backup.action_get,
        ) = self.original

    def test_dump(self):
        backup.dump()

        backup.mkdir.assert_called_once_with("this/dir")
        backup.execute.assert_called_once_with("mongodump -arg1 -arg2", "this/dir")
        backup.action_set.assert_has_calls(
            [
                call({"command": "mongodump -arg1 -arg2", "working-dir": "this/dir"}),
                call({"output": "output"}),
            ]
        )

    def test_restore(self):
        backup.restore()

        backup.mkdir.assert_called_once_with("this/dir")
        backup.execute.assert_called_once_with("mongorestore -arg1 -arg2", "this/dir")
        backup.action_set.assert_has_calls(
            [
                call(
                    {"command": "mongorestore -arg1 -arg2", "working-dir": "this/dir"}
                ),
                call({"output": "output"}),
            ]
        )


if __name__ == "__main__":
    unittest.main()
